.. modulegraph documentation master file, created by
   sphinx-quickstart on Tue Sep 28 21:04:40 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Modulegraph - Python module dependency graph
============================================

modulegraph determines a dependency graph between Python modules primarily
by bytecode analysis for import statements.

modulegraph uses similar methods to :mod:`modulefinder` from the standard library,
but uses a more flexible internal representation, has more extensive
knowledge of special cases, and is extensible.

Contents:

.. toctree::
   :maxdepth: 1

   changelog
   license
   commandline
   modulegraph
   find_modules
   util
   zipio

Online Resources
----------------

* `Sourcecode repository on GitHub <https://github.com/ronaldoussoren/modulegraph/>`_

* `The issue tracker <https://github.com/ronaldoussoren/modulegraph/issues>`_

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
